WYMeditor.STRINGS['cy'] = {
    Strong:           'Bras',
    Emphasis:         'Italig',
    Superscript:      'Uwchsgript',
    Subscript:        'Is-sgript',
    Ordered_List:     'Rhestr mewn Trefn',
    Unordered_List:   'Pwyntiau Bwled',
    Indent:           'Mewnoli',
    Outdent:          'Alloli',
    Undo:             'Dadwneud',
    Redo:             'Ailwneud',
    Link:             'Cysylltu',
    Unlink:           'Datgysylltu',
    Image:            'Delwedd',
    Table:            'Tabl',
    HTML:             'HTML',
    Paragraph:        'Paragraff',
    Heading_1:        'Pennawd 1',
    Heading_2:        'Pennawd 2',
    Heading_3:        'Pennawd 3',
    Heading_4:        'Pennawd 4',
    Heading_5:        'Pennawd 5',
    Heading_6:        'Pennawd 6',
    Preformatted:     'Rhagfformat',
    Blockquote:       'Bloc Dyfyniad',
    Table_Header:     'Pennyn Tabl',
    URL:              'URL',
    Title:            'Teitl',
    Alternative_Text: 'Testun Amgen',
    Caption:          'Pennawd',
    Summary:          'Crynodeb',
    Number_Of_Rows:   'Nifer y rhesi',
    Number_Of_Cols:   'Nifer y colofnau',
    Submit:           'Anfon',
    Cancel:           'Diddymu',
    Choose:           'Dewis',
    Preview:          'Rhagolwg',
    Paste_From_Word:  'Gludo o Word',
    Tools:            'Offer',
    Containers:       'Cynhwysyddion',
    Classes:          'Dosbarthiadau',
    Status:           'Statws',
    Source_Code:      'Cod ffynhonnell'
};

