WYMeditor.STRINGS['zh_cn'] = {
    Strong: '加粗',
    Emphasis: '斜体',
    Superscript: '上标',
    Subscript: '下标',
    Ordered_List: '有序列表',
    Unordered_List: '无序列表',
    Indent: '增加缩进',
    Outdent: '减少缩进',
    Undo: '撤消',
    Redo: '重做',
    Link: '链接',
    Unlink: '取消链接',
    Image: '图片',
    Table: '表格',
    HTML: 'HTML源代码',
    Paragraph: '段落',
    Heading_1: '标题 1',
    Heading_2: '标题 2',
    Heading_3: '标题 3',
    Heading_4: '标题 4',
    Heading_5: '标题 5',
    Heading_6: '标题 6',
    Preformatted: '原始文本',
    Blockquote: '引语',
    Table_Header: '表头',
    URL: '地址',
    Title: '提示文字',
    Alternative_Text: '失效文字',
    Caption: '标题',
    Summary: 'Summary',
    Number_Of_Rows: '行数',
    Number_Of_Cols: '列数',
    Submit: '提交',
    Cancel: '放弃',
    Choose: '选择',
    Preview: '预览',
    Paste_From_Word: '从Word粘贴纯文本',
    Tools: '工具',
    Containers: '容器',
    Classes: '预定义样式',
    Status: '状态',
    Source_Code: '源代码',
    Attachment: '附件',
    NewParagraph: '新段落'
};

