WYMeditor.STRINGS['pt'] = {
    Strong:           'Negrito',
    Emphasis:         'Itálico',
    Superscript:      'Sobrescrito',
    Subscript:        'Subsescrito',
    Ordered_List:     'Lista Numerada',
    Unordered_List:   'Lista Marcada',
    Indent:           'Aumentar Indentaçã',
    Outdent:          'Diminuir Indentaçã',
    Undo:             'Desfazer',
    Redo:             'Restaurar',
    Link:             'Link',
    Unlink:           'Tirar link',
    Image:            'Imagem',
    Table:            'Tabela',
    HTML:             'HTML',
    Paragraph:        'Parágrafo',
    Heading_1:        'Título 1',
    Heading_2:        'Título 2',
    Heading_3:        'Título 3',
    Heading_4:        'Título 4',
    Heading_5:        'Título 5',
    Heading_6:        'Título 6',
    Preformatted:     'Pré-formatado',
    Blockquote:       'Citação',
    Table_Header:     'Cabeçalho Tabela',
    URL:              'URL',
    Title:            'Título',
    Alternative_Text: 'Texto Alterativo',
    Caption:          'Título Tabela',
    Summary:          'Summary',
    Number_Of_Rows:   'Número de Linhas',
    Number_Of_Cols:   'Número de Colunas',
    Submit:           'Enviar',
    Cancel:           'Cancelar',
    Choose:           'Escolha',
    Preview:          'Prever',
    Paste_From_Word:  'Colar do Word',
    Tools:            'Ferramentas',
    Containers:       'Containers',
    Classes:          'Classes',
    Status:           'Status',
    Source_Code:      'Código Fonte'
};

